#! /usr/bin/env bash

alias @ai=bluer_ai
alias @i=bluer_ai

alias @assets=bluer_objects_assets

alias @create_test_asset=bluer_objects_create_test_asset

alias @download=bluer_objects_download

alias @gif=bluer_objects_gif

alias @cache=bluer_objects_mlflow_cache
alias @ref="bluer_objects_mlflow_cache read"
alias @tags=bluer_objects_mlflow_tags

alias @clone=bluer_objects_clone
alias @cp=bluer_objects_clone

alias @file=bluer_objects_file

alias @host=bluer_objects_host

alias @ls=bluer_objects_ls

alias @lock=bluer_objects_mlflow_lock

alias @metadata=bluer_objects_metadata

alias @mlflow=bluer_objects_mlflow

alias @mysql=abcli_mysql

alias @objects=bluer_objects

alias @pdf=bluer_objects_pdf

alias @random=bluer_ai_string_random

alias @select=bluer_ai_select

alias @storage=bluer_ai_storage

alias @upload=bluer_objects_upload

alias @web=bluer_objects_web
